document.addEventListener('DOMContentLoaded', () => {
  const searchForm = document.getElementById('searchForm');
  const loading = document.getElementById('loading');
  const error = document.getElementById('error');
  const results = document.getElementById('results');
  const projectsGrid = results.querySelector('.projects-grid');

  searchForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    const username = document.getElementById('username').value.trim();
    
    if (!username) return;

    showLoading();
    
    try {
      // Get user's starred repos
      const starredRepos = await fetchStarredRepos(username);
      
      // Get repos with good first issues
      const recommendations = await findRecommendations(starredRepos);
      
      displayResults(recommendations);
    } catch (err) {
      showError(err.message);
    }
  });

  async function fetchStarredRepos(username) {
    const response = await fetch(`https://api.github.com/users/${username}/starred`);
    if (!response.ok) {
      throw new Error('Unable to fetch starred repositories. Please check the username and try again.');
    }
    return response.json();
  }

  async function findRecommendations(starredRepos) {
    const topics = extractTopics(starredRepos);
    const recommendations = [];
    
    for (const topic of topics) {
      const response = await fetch(
        `https://api.github.com/search/issues?q=label:"good first issue"+state:open+topic:${topic}`
      );
      const data = await response.json();
      recommendations.push(...data.items.slice(0, 3));
    }
    
    return recommendations.slice(0, 9);
  }

  function extractTopics(repos) {
    const topicsMap = {};
    repos.forEach(repo => {
      repo.topics?.forEach(topic => {
        topicsMap[topic] = (topicsMap[topic] || 0) + 1;
      });
    });
    
    return Object.entries(topicsMap)
      .sort((a, b) => b[1] - a[1])
      .slice(0, 3)
      .map(([topic]) => topic);
  }

  function displayResults(recommendations) {
    projectsGrid.innerHTML = '';
    
    recommendations.forEach(issue => {
      const card = document.createElement('article');
      card.className = 'project-card';
      card.innerHTML = `
        <h3>${issue.repository_url.split('/').slice(-1)}</h3>
        <p>${issue.title}</p>
        <a href="${issue.html_url}" target="_blank" rel="noopener noreferrer">View Issue</a>
      `;
      projectsGrid.appendChild(card);
    });
    
    hideLoading();
    results.classList.remove('hidden');
  }

  function showLoading() {
    error.classList.add('hidden');
    results.classList.add('hidden');
    loading.classList.remove('hidden');
  }

  function hideLoading() {
    loading.classList.add('hidden');
  }

  function showError(message) {
    hideLoading();
    results.classList.add('hidden');
    error.querySelector('p').textContent = message;
    error.classList.remove('hidden');
  }
});
